@@ -1,7 +1,11 @@
-import csv
+import csv, pandas
 
 def load_csv():
     with open('csvloaderData/data.csv','rt')as f:
         data = csv.reader(f)
         for row in data:
-            print(row)
\ No newline at end of file
+            print(row)
+
+def load_pandas():
+    result = pandas.read_csv('csvloaderData/data.csv')
+    print(result)
\ No newline at end of file
